# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

upload command
C:\Anaconda3\python.exe -m twine upload --repository-url https://test.pypi.org/legacy/ dist/*
C:\Anaconda3\python.exe -m twine upload dist/*

